@@ -9,16 +9,11 @@ Michael Hucka <mhucka@caltech.edu> -- Caltech Library
 Copyright
 ---------
 
-Copyright (c) 2021 by the California Institute of Technology.  This code
+Copyright (c) 2021-2023 by the California Institute of Technology.  This code
 is open-source software released under a 3-clause BSD license.  Please see the
 file "LICENSE" for more information.
 '''
 
-if __debug__:
-    from sidetrack import log
-
-from .exceptions import DataMismatchError
-
 
 # Class definitions.
 # .............................................................................
